@@ -634,14 +634,15 @@ class GraspManager(ActivityBase):
                     if self.has_obj:
                         self.object_c_manager.set_transform(self.obj_info["name"], result_obj_pose)
 
+                    if not self._check_between_object_distances(eps=0.03):
+                        continue
+
                     if self._check_ik_solution(post_release_pose, post_release_goal_pose) and self._collision_free(post_release_transforms):
                         self.post_release_pose = post_release_pose
                         self.obj_release_pose = result_obj_pose
                         self.obj_post_release_pose = result_obj_pose
-                        
-                        if self._check_between_object_distances(eps=0.005):
-                            is_success_filtered = True
-                            break
+                        is_success_filtered = True
+                        break
 
         if not is_success_filtered:
             logger.error(f"Failed to filter Release poses")
@@ -658,7 +659,7 @@ class GraspManager(ActivityBase):
         obj_mesh,
         obj_pose,
         n_samples,
-        alpha=0.9
+        alpha=0.99
     ):
         """
         Generate support points
@@ -679,7 +680,7 @@ class GraspManager(ActivityBase):
         weights = np.zeros(len(copied_mesh.faces))
         for idx, vertex in enumerate(copied_mesh.vertices[copied_mesh.faces]):
             weights[idx]=0.0
-            if np.all(vertex[:,2] >= copied_mesh.bounds[1][2] * 0.98):
+            if np.all(vertex[:,2] >= copied_mesh.bounds[1][2] * 0.99):
                 weights[idx] = 1.0
 
         support_points, _, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
